===============================================================
``psyclone.domain.gocean.transformations.gocean_extract_trans``
===============================================================

.. automodule:: psyclone.domain.gocean.transformations.gocean_extract_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.gocean.transformations.gocean_extract_trans
